#ifndef __FILE_USUAL_H_SEEN__
#pragma once
#define __FILE_USUAL_H_SEEN__ 1


#undef    TURBO_CPP_COMPILER
#define   GNU_GPP_COMPILER    1

#define   USE_ATT_STYLE_IO_WITH_GNU  1 
#undef    USE_GNU_STYLE_IO_WITH_GNU   


/* -------------------------  References  ---------------------------------

Bjarne Stroustrup (1986), The C++ Programming Language. Reading Massachusetts: 
Addison-Wesley Publishing Company.

    Header files:

    <complex.h>     p. 123, 173
    <ctype.h>       p.  77, 237
    <math.h>        p.  22, 115
    <signal.h>      p. 126 
    <stdargs.h>     p. 124
    <stream.h>      p.  12, 226
    <string.h>      p. 111
    <vector.h>      p.  35



Kernigham, Brian W., and Dennis M. Ritchie (1988).  The C Programming Language, 
Second Edition.  Englewood Cliffs, New Jersey: Prentice Hall.


    Appendix B. Standard Library

    B1  Input and Output:                <stdio.h>                  p. 241
    B2  Character Class Tests:           <ctype.h>                  p. 248
    B3  String Functions:                <string.h>                 p. 249
    B4  Mathematical Functions:          <math.h>                   p. 250
    B5  Utility Functions:               <stdlib.h>                 p. 251
    B6  Diagnostics                      <assert.h>                 p. 253
    B7  Variable Argument Lists:         <stdarg.h>                 p. 254
    B8  Non-Local Jumps                  <setjump.h>                p. 254
    B9  Signals:                         <signal.h>                 p. 255
    B10 Date and Time Functions          <time.h>                   p. 255
    B11 Implementation-defined Limits:   <limits.h> and <float.h>   p. 257

---------------------------------------------------------------------------*/

/*--------------------------- g++ -------------------------------------------

GNU's g++ follows Stroustrup.  These are the g++ equivalents together with 
their dependencies.

<Complex.h>
  <File.h> <builtin.h> <errno.h> <istream.h> <math.h> <math-68881.h>
  <ostream.h> <std.h> <stddef.h> <stdio.h> <stream.h> <streambuf.h> 
  <values.h>

<ctype.h>
  <stdio.h>

<math.h>
  <errno.h> <math-68881.h> <std.h> <stddef.h> <stdio.h> 

<signal.h>
  <sys/signal.h>

<std.h>
  <stdio.h> <stddef.h>

<stream.h>
  <File.h> <builtin.h> <errno.h> <istream.h> <math.h> <math-68881.h>  
  <ostream.h> <std.h> <stddef.h> <stdio.h> <streambuf.h> <values.h>

<string.h>
  <std.h> <stddef.h> <stdio.h>

<Vec.hP> & <Vec.ccP>
  <stream.h>

The USE_ATT_STYLE_IO_WITH_GNU option uses the streambuf class which conforms 
to Chapter 8 of Stroustrup.  

The USE_GNU_STYLE_IO_WITH_GNU option uses the File class.  This is unreliable,
piping sometimes corrupts I/O for example, but this is all there is on older
releases of g++.

----------------------------------------------------------------------------*/

#ifdef GNU_GPP_COMPILER
#include <stream.h>
#endif 


/*---------------------------- Turbo C++ ------------------------------------

Turbo C++ uses a tiresome mixture of ANSI C headers and Stroustrup headers.  
See page 155 of the Turbo C++ Programmers Guide for a description.

----------------------------------------------------------------------------*/ 

#ifdef TURBO_CPP_COMPILER
#include <iostreams.h>
#include <fstream.h>
#include <stdio.h>
#include <string.h>
#include <math.h>
#include <stdlib.h>
#endif  

#define LINESIZE  80         // define linesize for output routines

typedef long int  INTEGER;   // define precision of integer arithmetic
typedef double    REAL;      // define precision of floating point arithmetic

typedef void (*ONE_ARG_ERROR_HANDLER_T)(const char*);              
typedef void (*TWO_ARG_ERROR_HANDLER_T)(const char*, const char*);

#endif /*__FILE_USUAL_H_SEEN__*/
